/**
***  Error signalling.  error() dumps core if debug_on_error is non-zero.
***  (Note: parse_args() sets debug_on_error if it receives the flag -debug.)
***  dump_core() always dumps core.
**/


#include <stdio.h>
#include <stdlib.h>
#include <varargs.h>
#include <errno.h>


int debug_on_error = 0;


int error (va_alist)
    va_dcl
{
  va_list args;
  char *fmt;
  
  va_start(args);
  fprintf(stderr, "**ERROR  ");
  fmt = va_arg(args, char *);
  vfprintf(stderr, fmt, args);
  if (errno > 0) {
      fprintf(stderr, " -- %d: ", errno);
      perror(NULL);
  }
  else putc('\n', stderr);
  va_end(args);
  
  fflush(stderr);
  if (debug_on_error)
    abort();
  else
    exit(1);
}


int dump_core (va_alist)
    va_dcl
{
  va_list args;
  char *fmt;
  
  va_start(args);
  fprintf(stderr, "**ERROR  ");
  fmt = va_arg(args, char *);
  vfprintf(stderr, fmt, args);
  if (errno > 0) {
      fprintf(stderr, " -- ");
      perror(NULL);
  }
  else putc('\n', stderr);
  va_end(args);
  
  fflush(stderr);
  errno = 0;
  abort();
}


void trace (va_alist)
    va_dcl
{
    va_list args;
    int on;
    char *fmt;

    va_start(args);
    on = va_arg(args, int);
    if (on) {
	fmt = va_arg(args, char *);
	vfprintf(stderr, fmt, args);
	putc('\n', stderr);
    }
    va_end(args);
}

